Hiisi
======
The main idea behind hiisi module is to make the handling of hdf5 -files as
fluent as possible. Module contains higher level tools such as search and
write methods that are build on top of h5py module.
